import type { TypstParser } from '@myriaddreamin/typst-ts-parser';
export interface SemanticTokensLegend {
    readonly tokenTypes: string[];
    readonly tokenModifiers: string[];
}
export interface SemanticTokens {
    /**
     * The result id of the tokens.
     *
     * This is the id that will be passed to `DocumentSemanticTokensProvider.provideDocumentSemanticTokensEdits` (if implemented).
     */
    readonly resultId?: string;
    readonly data: Uint32Array;
}
interface SemanticTokensProviderStyling {
    getMetadata(tokenTypeIndex: number, tokenModifierSet: number, languageId: string): number;
    warnInvalidLengthSemanticTokens(lineNumber: number, startCharacter: number): void;
    warnOverlappingSemanticTokens(lineNumber: number, startCharacter: number): void;
}
type SparseMultilineTokens = [number, Uint32Array];
/**
 * https://github.com/microsoft/vscode/blob/main/src/vs/editor/common/services/semanticTokensProviderStyling.ts#L142
 */
export declare function toMultilineTokens2(tokens: SemanticTokens, styling: SemanticTokensProviderStyling, languageId: string): SparseMultilineTokens[];
export declare function initHljs(): Promise<TypstParser>;
/**
 * Options for the `hljsTypst` function.
 * @param handleCodeBlocks - Whether to handle code blocks.
 *   Defaults to true.
 *   If set to false, code blocks will be rendered as plain code blocks.
 *   If set to true, a default handler will be used.
 *   If set to a function, the function will be used as the handler.
 *
 *   When the `hljsTypst` has a code block handler, the code block will be called with the code block content and the emitter.
 *
 *   If the handler return false, the code block will be still rendered as plain code blocks.
 *
 * @param codeBlockDefaultLanguage - The default language for code blocks.
 *   Defaults to undefined.
 */
export interface TypstHljsOptions {
    handleCodeBlocks?: boolean | ((code: string, emitter: any) => boolean);
    codeBlockDefaultLanguage?: string;
}
/**
 * A function that constructs a language definition for hljs
 * @param options options for the hljsTypst function.
 * @returns a language definition for hljs.
 * See {@link TypstHljsOptions} for more details.
 *
 * @example
 *
 * Default usage:
 * ```ts
 * hljs.registerLanguage('typst', window.hljsTypst());
 * ```
 *
 * @example
 *
 * Don't handle code blocks:
 * ```ts
 * hljs.registerLanguage('typst', window.hljsTypst({
 *  handleCodeBlocks: false,
 * }));
 *
 * @example
 *
 * Handle code blocks with a custom function:
 * ```ts
 * hljs.registerLanguage('typst', window.hljsTypst({
 *   handleCodeBlocks: (code, emitter) => {
 *     return false;
 *   });
 * }));
 * ```
 *
 * @example
 *
 * Set the default language for code blocks:
 * ```ts
 * hljs.registerLanguage('typst', window.hljsTypst({
 *  codeBlockDefaultLanguage: 'rust',
 * }));
 * ```
 */
export declare function hljsTypst(options?: TypstHljsOptions): (hljs: any) => {
    case_insensitive: boolean;
    keywords: string[];
    contains: never[];
    __emitTokens: (code: string, emitter: any) => void;
};
export {};
//# sourceMappingURL=hljs.d.mts.map